#!/bin/sh
# ****************************************************************** 
#  Copyright (c) 2011, SAS Institute Inc., Cary, NC USA
#  ---All Rights Reserved.
# ******************************************************************
#
# applyHotFix.bat
#
# Two positional variables must be passed in on the command line
#
# $1 OMRPW - this is the password for the SAS administrative user id
# $2 CFGLEVDIR - this is the configuration directory path
#
# Additional requirements:
#  From the shell invoking the script:
#   Set and export the DISPLAY environment variable for the X11 display
#
#   If the level_env.sh file in the configuration directory does not
#   define a JDK_HOME environment variable, then that must be defined
#   and exported.

runScript()
{
  . "$CFGLEVDIR/level_env.sh"
  export LEVEL_ROOT

  STDLOGNAME=itrmhotfix.log
  export STDLOGNAME

  TWELVEBYTE=itrmdatatier
  export TWELVEBYTE

  echo ""
  echo "Output from this script is redirected to the log file: $STDLOGNAME"
  echo ""

  "$CFGLEVDIR/Utilities/launchconfigtarget.sh" -Ditrmdatatier.cfgprops.file="$CFGLEVDIR/Utilities/$TWELVEBYTE.configuration.properties" -Dmetadata.connection.passwd=$OMRPW -f "$SAS_HOME/SASITResourceManagementDataTier/3.3/Config/itrmhotfix.xml" applyHotFix

  doTerm
}

badArgs()
{
  echo ""
  echo " Incorrect arguments passed to shell script."
  echo ""
  echo " Usage:"
  echo "         applyHotFix.sh [password]  [config-dir]"
  echo ""
  echo "         Example: applyHotFix.sh MyPass1 /SAS/Config/Lev1"
  doTerm
}

doTerm()
{
  echo ""
  echo "applyHotFix.sh has completed."
  exit
}

if [ $# -ne 2 ]
then
  badArgs
else
  OMRPW=
  CFGLEVDIR=
  OMRPW=$1
  CFGLEVDIR=$2
  runScript
fi

