%macro rmverchk();
 /*+----------------------------------------------------------------+
   | Copyright (C) 2008 by SAS Institute Inc., Cary, NC 27512-8000
   | Name:     RMVERCHK.SAS
   | Product:  SAS IT Management Solutions
   | Language: SAS
   | Usage:
   |
   | Purpose:  To verify and report on versions of various software
   |           components
   | History:  date    defect
   |           04Feb08 Initial Coding                             CDW
   |           25Aug08 S0501902 Remove javaobj where possible     CLS
   |           11Sep08 S0517014 Improve message content           CDW
   |           12Sep08 S0518481 Check metadata connection first   CDW
   |           04Nov08 S0544307 Support encodings on metadata
   |                            datastep functions                CDW
   |           14Nov08 S0548219 Reposition commas to avoid macro
   |                            string parsing error              CDW
   |           04Feb10 S0641649 Revise for ITRM 3.2               JTR
   |           01Jun10 S0673909 Remove encodings on metadata
   |                            datastep functions                CDW
   |           08Feb11 S0738111 Update version and portdate string
   |                            for release 3.2.1                 CDW
   |           10Oct11 S0799188 Update version and portdate string
   |                            for release 3.3 and add a warning
   |                            message if software component
   |                            cannot be found                   CDW
   |           17Apr13 S0882423 Remove bad version test by
   |                            simplifying the checks as per
   |                            S0918545 made at 3.4 and modify
   |                            macro version string for 303002   CDW
   | Future:
   | Notes:
   |
   +----------------------------------------------------------------+*/

  %let itrm_macro_version=303002.20130417;  /* This changes with */
                                            /* every push to mva */

  %rmcrmsg;

  filename itmsver catalog 'sashelp.itms.version.source';

  %local elementCount;
  %let elementCount = 2;
  %global rmloggerlevel;
  %if "&rmloggerlevel" eq "" %then %let rmloggerlevel=3;

  %local serverVersionIndex;
  %local macroVersionIndex;

  %let serverVersionIndex           = 1;
  %let macroVersionIndex            = 2;

  data _null_;
    %rmmsgint;

    array version{&elementCount} $ 40
                          ServerVersion
                          MacroVersion
       ( &elementCount * '');
    length srvPrefix macPrefix $ 4;

    array version_info_msg_key{&elementCount} $ 42 _temporary_
                              ('server_cat_version_logInfo'
                               'server_mac_version_logInfo'
                               );

    /* Grab the ServerVersion from SASHELP.ITMS.VERSION.SOURCE  */
    /*                                                          */
    infile itmsver;
    input ServerVersion;

    /* Grab the software version of this macro                  */
    /*                                                          */
    MacroVersion="&itrm_macro_version";

    srvPrefix=version{&serverVersionIndex};
    macPrefix=version{&macroVersionIndex};

    if (srvPrefix=macPrefix) then
        checkedok=1;

    if checkedok ne 1 then do;
       _msgTxt = resolve('%rmmsg(SASHELP.ITMS,' !!
                        'major_version_conflict_logWarn' !!
                        ',noquote)');
       _msgRc = resolve('%rmLogWrn(ITMS,'!! _msgTxt !!')');
       end;

    do x=1 to dim(version);
      _msgTxt = resolve('%rmmsg(SASHELP.ITMS,' !!
                        version_info_msg_key{x} !!
                        ',noquote,' !!
                        version{x}  !! ')');
      _msgRc = resolve('%rmLogInf(ITMS,'!! _msgTxt !!')');
    end;

    stop;

  run;

  filename itmsver clear;

  %* Do not set ITMSRC here since we do not want to cause repercussions;
  %let itmsrc=0;

%mend rmverchk;
